libidav/davqlparser.h

changeset 127
7072a2b4ae35
parent 121
eea36bf5ffe2
child 130
80d273229f24
--- a/libidav/davqlparser.h	Sat May 30 21:43:36 2015 +0200
+++ b/libidav/davqlparser.h	Tue Jun 02 10:07:20 2015 +0200
@@ -40,7 +40,7 @@
 /**
  * Enumeration of possible statement types.
  */
-typedef enum {DAVQL_ERROR, DAVQL_GET, DAVQL_SET} davqltype_t;
+typedef enum {DAVQL_ERROR, DAVQL_SELECT, DAVQL_SET} davqltype_t;
 
 /**
  * Enumeration of possible token classes.
@@ -135,7 +135,7 @@
     /**
      * The field name.
      * <ul>
      * <li>GET: the identifier or an alias name</li>
      * <li>SET: the identifier</li>
      * </ul>
      */
@@ -143,7 +143,7 @@
     /**
      * The field expression.
      * <ul>
      * <li>GET: the queried property (identifier) or an expression</li>
      * <li>SET: the expression for the value to be set</li>
      * </ul>
      */
@@ -215,9 +215,9 @@
  * arbitrary amount of optional spaces between two symbols if they are not part
  * of an literal or identifier.
  * 
- * <b>GET:</b>
+ * <b>SELECT:</b>
  * <pre>
- * GetStatement = "get ", FieldExpressions,
+ * SelectStatement = "select ", FieldExpressions,
  * " from ", Path,
  * [" with ", WithClause],
  * [" where ", LogicalExpression],
@@ -135,7 +135,7 @@
      * The field name.
      * <ul>
-     * <li>GET: the identifier or an alias name</li>
+     * <li>SELECT: the identifier or an alias name</li>
      * <li>SET: the identifier</li>
      * </ul>
@@ -143,7 +143,7 @@
      * The field expression.
      * <ul>
-     * <li>GET: the queried property (identifier) or an expression</li>
+     * <li>SELECT: the queried property (identifier) or an expression</li>
      * <li>SET: the expression for the value to be set</li>
      * </ul>

mercurial